@@ -24,10 +24,19 @@ class ParseError(RuntimeError):
 class DocstringStyle(enum.Enum):
     """Docstring style."""
 
-    rest = 1
-    google = 2
-    numpydoc = 3
-    auto = 255
+    REST = 1
+    GOOGLE = 2
+    NUMPYDOC = 3
+    EPYDOC = 4
+    AUTO = 255
+
+
+class RenderingStyle(enum.Enum):
+    """Rendering style when unparsing parsed docstrings."""
+
+    COMPACT = 1
+    CLEAN = 2
+    EXPANDED = 3
 
 
 class DocstringMeta:
@@ -39,12 +48,14 @@ class DocstringMeta:
         :raises ValueError: if something happens
     """
 
-    def __init__(self, args: T.List[str], description: str) -> None:
+    def __init__(
+        self, args: T.List[str], description: T.Optional[str]
+    ) -> None:
         """Initialize self.
 
         :param args: list of arguments. The exact content of this variable is
-                     dependent on the kind of docstring; it's used to distinguish between
-                     custom docstring meta information items.
+            dependent on the kind of docstring; it's used to distinguish
+            between custom docstring meta information items.
         :param description: associated docstring description.
         """
         self.args = args
@@ -136,16 +147,24 @@ class Docstring:
 
     @property
     def params(self) -> T.List[DocstringParam]:
+        """Return a list of information on function params."""
         return [item for item in self.meta if isinstance(item, DocstringParam)]
 
     @property
     def raises(self) -> T.List[DocstringRaises]:
+        """Return a list of information on the exceptions that the function
+        may raise.
+        """
         return [
             item for item in self.meta if isinstance(item, DocstringRaises)
         ]
 
     @property
     def returns(self) -> T.Optional[DocstringReturns]:
+        """Return a single information on function return.
+
+        Takes the first return information.
+        """
         for item in self.meta:
             if isinstance(item, DocstringReturns):
                 return item
@@ -153,12 +172,14 @@ class Docstring:
 
     @property
     def many_returns(self) -> T.List[DocstringReturns]:
+        """Return a list of information on function return."""
         return [
             item for item in self.meta if isinstance(item, DocstringReturns)
         ]
 
     @property
     def deprecation(self) -> T.Optional[DocstringDeprecated]:
+        """Return a single information on function deprecation notes."""
         for item in self.meta:
             if isinstance(item, DocstringDeprecated):
                 return item
